# yamt (yet another monkey toolkit)
[![PyPI version](https://badge.fury.io/py/yamt.svg)](https://badge.fury.io/py/yamt)
![PyPI downloads per mounth](https://img.shields.io/pypi/dm/yamt)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/UT1C/yamt)

## Installation
```
pip install yamt
```
